@@ -99,7 +99,8 @@ pub trait VerificationPredicates: Send + Sync {
         trusting_period: Duration,
         now: Time,
     ) -> Result<(), VerificationError> {
-        let expires_at = trusted_header_time + trusting_period;
+        let expires_at =
+            (trusted_header_time + trusting_period).map_err(VerificationError::tendermint)?;
 
         if expires_at > now {
             Ok(())
@@ -115,7 +116,9 @@ pub trait VerificationPredicates: Send + Sync {
         clock_drift: Duration,
         now: Time,
     ) -> Result<(), VerificationError> {
-        if untrusted_header_time < now + clock_drift {
+        let drifted = (now + clock_drift).map_err(VerificationError::tendermint)?;
+
+        if untrusted_header_time < drifted {
             Ok(())
         } else {
             Err(VerificationError::header_from_the_future(
@@ -202,9 +205,11 @@ pub trait VerificationPredicates: Send + Sync {
 
 #[cfg(test)]
 mod tests {
-    use std::ops::Sub;
+    use std::convert::TryInto;
     use std::time::Duration;
-    use tendermint::Time;
+    use tendermint::block::CommitSig;
+    use tendermint::validator::Set;
+    use time::OffsetDateTime;
 
     use tendermint_testgen::{
         light_block::{LightBlock as TestgenLightBlock, TmLightBlock},
@@ -220,8 +225,6 @@ mod tests {
         Hasher, ProdCommitValidator, ProdHasher, ProdVotingPowerCalculator, VotingPowerTally,
     };
     use crate::types::{LightBlock, TrustThreshold};
-    use tendermint::block::CommitSig;
-    use tendermint::validator::Set;
 
     impl From<TmLightBlock> for LightBlock {
         fn from(lb: TmLightBlock) -> Self {
@@ -290,7 +293,7 @@ mod tests {
 
         // 1. ensure valid header verifies
         let mut trusting_period = Duration::new(1000, 0);
-        let now = Time::now();
+        let now = OffsetDateTime::now_utc().try_into().unwrap();
 
         let result_ok = vp.is_within_trust_period(header.time, trusting_period, now);
         assert!(result_ok.is_ok());
@@ -300,7 +303,7 @@ mod tests {
 
         let result_err = vp.is_within_trust_period(header.time, trusting_period, now);
 
-        let expires_at = header.time + trusting_period;
+        let expires_at = (header.time + trusting_period).unwrap();
         match result_err {
             Err(VerificationError(VerificationErrorDetail::NotWithinTrustPeriod(e), _)) => {
                 assert_eq!(e.expires_at, expires_at);
@@ -318,13 +321,15 @@ mod tests {
         let vp = ProdPredicates::default();
         let one_second = Duration::new(1, 0);
 
+        let now = OffsetDateTime::now_utc().try_into().unwrap();
+
         // 1. ensure valid header verifies
-        let result_ok = vp.is_header_from_past(header.time, one_second, Time::now());
+        let result_ok = vp.is_header_from_past(header.time, one_second, now);
 
         assert!(result_ok.is_ok());
 
         // 2. ensure it fails if header is from a future time
-        let now = Time::now().sub(one_second * 15);
+        let now = (now - one_second * 15).unwrap();
         let result_err = vp.is_header_from_past(header.time, one_second, now);
 
         match result_err {
